from setuptools import setup 
setup(
    name='harlask3',
    version = '0.0.3',
    description='functions for the harley desktop assistant',
    package_dir = {'': 'src'},
    py_modules = ["harlask2"],
    author =  "Ayush Dutta",
    license = "MIT",
    url = "https://github.com/bravosickz/harlask"
)
